@@ -237,7 +237,6 @@ EXCLUDE = (
     "lib/common/types.h",
     "lib/common/usershape.h",
     "lib/common/utils.c",
-    "lib/common/xml.c",
     "lib/dotgen/acyclic.c",
     "lib/dotgen/aspect.c",
     "lib/dotgen/aspect.h",
@@ -500,11 +499,8 @@ EXCLUDE = (
     "lib/pathplan/vis.h",
     "lib/pathplan/visibility.c",
     "lib/pathplan/vispath.h",
-    "lib/rbtree/misc.c",
     "lib/rbtree/red_black_tree.c",
     "lib/rbtree/red_black_tree.h",
-    "lib/rbtree/stack.c",
-    "lib/rbtree/stack.h",
     "lib/rbtree/test_red_black_tree.c",
     "lib/sfdpgen/Multilevel.c",
     "lib/sfdpgen/Multilevel.h",
@@ -538,13 +534,11 @@ EXCLUDE = (
     "lib/sfio/sfnputc.c",
     "lib/sfio/sfopen.c",
     "lib/sfio/sfpkrd.c",
-    "lib/sfio/sfprintf.c",
     "lib/sfio/sfputr.c",
     "lib/sfio/sfraise.c",
     "lib/sfio/sfrd.c",
     "lib/sfio/sfread.c",
     "lib/sfio/sfscanf.c",
-    "lib/sfio/sfseek.c",
     "lib/sfio/sfsetbuf.c",
     "lib/sfio/sfsetfd.c",
     "lib/sfio/sfsk.c",
@@ -553,7 +547,7 @@ EXCLUDE = (
     "lib/sfio/sfsync.c",
     "lib/sfio/sftable.c",
     "lib/sfio/sfungetc.c",
-    "lib/sfio/sfvprintf.c",
+    "lib/sfio/sfprint.c",
     "lib/sfio/sfvscanf.c",
     "lib/sfio/sfwr.c",
     "lib/sfio/sfwrite.c",
