@@ -8,11 +8,13 @@
  * Contributors: Details at https://graphviz.org
  *************************************************************************/
 
+#include <limits.h>
 #include <stdbool.h>
 #include <stddef.h>
 #include <stdio.h>		/* need sprintf() */
 #include <ctype.h>
 #include <cgraph/cghdr.h>
+#include <cgraph/likely.h>
 #include <cgraph/strcasecmp.h>
 #include <inttypes.h>
 
@@ -33,7 +35,6 @@ static int ioput(Agraph_t * g, iochan_t * ofile, char *str)
 static int write_body(Agraph_t * g, iochan_t * ofile);
 static int Level;
 static int Max_outputline = MAX_OUTPUTLINE;
-static unsigned char Attrs_not_written_flag;
 static Agsym_t *Tailport, *Headport;
 
 static int indent(Agraph_t * g, iochan_t * ofile)
@@ -59,7 +60,7 @@ static char *_agstrcanon(char *arg, char *buf)
     char uc;
     int cnt = 0, dotcnt = 0;
     bool needs_quotes = false;
-    int maybe_num;
+    bool maybe_num;
     bool backslash_pending = false;
     static const char *tokenlist[]	/* must agree with scan.l */
 	= { "node", "edge", "strict", "graph", "digraph", "subgraph",
@@ -73,7 +74,7 @@ static char *_agstrcanon(char *arg, char *buf)
     p = buf;
     *p++ = '\"';
     uc = *s++;
-    maybe_num = isdigit(uc) || uc == '.' || uc == '-';
+    maybe_num = isdigit(uc) != 0 || uc == '.' || uc == '-';
     while (uc) {
 	if (uc == '\"') {
 	    *p++ = '\\';
@@ -82,22 +83,22 @@ static char *_agstrcanon(char *arg, char *buf)
 	else if (maybe_num) {
 	    if (uc == '-') {
 		if (cnt) {
-		    maybe_num = FALSE;
+		    maybe_num = false;
 		    needs_quotes = true;
 		}
 	    }
 	    else if (uc == '.') {
 		if (dotcnt++) {
-		    maybe_num = FALSE;
+		    maybe_num = false;
 		    needs_quotes = true;
 		}
 	    }
 	    else if (!isdigit(uc)) {
-		maybe_num = FALSE;
+		maybe_num = false;
 		needs_quotes = true;
 	    }
 	}
-	else if (!ISALNUM(uc))
+	else if (!(isalnum(uc) || uc == '_' || !isascii(uc)))
 	    needs_quotes = true;
 	*p++ = uc;
 	uc = *s++;
@@ -168,7 +169,10 @@ static char *getoutputbuffer(const char *str)
 
     req = MAX(2 * strlen(str) + 2, BUFSIZ);
     if (req > len) {
-	rv = realloc(rv, req);
+	char *r = realloc(rv, req);
+	if (UNLIKELY(r == NULL))
+	    return NULL;
+	rv = r;
 	len = req;
     }
     return rv;
@@ -181,7 +185,10 @@ static char *getoutputbuffer(const char *str)
  */
 char *agcanonStr(char *str)
 {
-    return agstrcanon(str, getoutputbuffer(str));
+    char *buffer = getoutputbuffer(str);
+    if (UNLIKELY(buffer == NULL))
+        return NULL;
+    return agstrcanon(str, buffer);
 }
 
 /*
@@ -192,6 +199,8 @@ char *agcanonStr(char *str)
 char *agcanon(char *str, int html)
 {
     char* buf = getoutputbuffer(str);
+    if (UNLIKELY(buf == NULL))
+	return NULL;
     if (html)
 	return agcanonhtmlstr(str, buf);
     else
@@ -201,10 +210,14 @@ char *agcanon(char *str, int html)
 static int _write_canonstr(Agraph_t * g, iochan_t * ofile, char *str,
 			   int chk)
 {
-    if (chk)
+    if (chk) {
 	str = agcanonStr(str);
-    else
-	str = _agstrcanon(str, getoutputbuffer(str));
+    } else {
+	char *buffer = getoutputbuffer(str);
+	if (UNLIKELY(buffer == NULL))
+	    return EOF;
+	str = _agstrcanon(str, buffer);
+    }
     return ioput(g, ofile, str);
 }
 
@@ -287,9 +300,8 @@ static int write_hdr(Agraph_t * g, iochan_t * ofile, int top)
     bool root = false;
     bool hasName = true;
 
-    Attrs_not_written_flag = AGATTRWF(g);
     strict = "";
-    if (NOT(top) && agparent(g))
+    if (!top && agparent(g))
 	kind = "sub";
     else {
 	root = true;
@@ -328,7 +340,7 @@ static int write_hdr(Agraph_t * g, iochan_t * ofile, int top)
 
 static int write_trl(Agraph_t * g, iochan_t * ofile)
 {
-    NOTUSED(g);
+    (void)g;
     Level--;
     CHKRV(indent(g, ofile));
     CHKRV(ioput(g, ofile, "}\n"));
@@ -398,7 +410,7 @@ static bool not_default_attrs(Agraph_t * g, Agnode_t * n)
     Agattr_t *data;
     Agsym_t *sym;
 
-    NOTUSED(g);
+    (void)g;
     if ((data = agattrrec(n))) {
 	for (sym = dtfirst(data->dict); sym; sym = dtnext(data->dict, sym)) {
 	    if (data->str[sym->id] != sym->defval)
@@ -433,7 +445,7 @@ static int write_edge_name(Agedge_t * e, iochan_t * ofile, int terminate)
 
     p = agnameof(e);
     g = agraphof(e);
-    if (NOT(EMPTY(p))) {
+    if (!EMPTY(p)) {
 	if (!terminate) {
 	    Level++;
 	}
@@ -489,7 +501,7 @@ static int write_nondefault_attrs(void *obj, iochan_t * ofile,
 	CHKRV(ioput(g, ofile, "]"));
 	Level--;
     }
-    AGATTRWF((Agobj_t *) obj) = TRUE;
+    AGATTRWF(obj) = TRUE;
     return 0;
 }
 
@@ -522,7 +534,7 @@ static int write_node(Agnode_t * n, iochan_t * ofile, Dict_t * d)
     g = agraphof(n);
     CHKRV(indent(g, ofile));
     CHKRV(write_nodename(n, ofile));
-    if (NOT(attrs_written(n)))
+    if (!attrs_written(n))
 	CHKRV(write_nondefault_attrs(n, ofile, d));
     return ioput(g, ofile, ";\n");
 }
@@ -599,7 +611,7 @@ static int write_edge(Agedge_t * e, iochan_t * ofile, Dict_t * d)
     CHKRV(ioput(g, ofile, (agisdirected(agraphof(t)) ? " -> " : " -- ")));
     CHKRV(write_nodename(h, ofile));
     CHKRV(write_port(e, ofile, Headport));
-    if (NOT(attrs_written(e))) {
+    if (!attrs_written(e)) {
 	CHKRV(write_nondefault_attrs(e, ofile, d));
     } else {
 	CHKRV(write_edge_name(e, ofile, TRUE));
@@ -657,12 +669,12 @@ static void set_attrwf(Agraph_t * g, bool toplevel, bool value)
 int agwrite(Agraph_t * g, void *ofile)
 {
     char* s;
-    int len;
     Level = 0;			/* re-initialize tab level */
-    if ((s = agget(g, "linelength")) && isdigit(*s)) {
-	len = (int)strtol(s, (char **)NULL, 10);
-	if (len == 0 || len >= MIN_OUTPUTLINE)
-	    Max_outputline = len;
+    s = agget(g, "linelength");
+    if (s != NULL && isdigit((int)*s)) {
+	unsigned long len = strtoul(s, NULL, 10);
+	if ((len == 0 || len >= MIN_OUTPUTLINE) && len <= (unsigned long)INT_MAX)
+	    Max_outputline = (int)len;
     }
     set_attrwf(g, true, false);
     CHKRV(write_hdr(g, ofile, TRUE));
