@@ -28,13 +28,12 @@
 /*
  *  a queue of nodes
  */
-nodequeue *new_queue(int sz)
-{
+nodequeue *new_queue(size_t sz) {
     nodequeue *q = gv_alloc(sizeof(nodequeue));
 
     if (sz <= 1)
 	sz = 2;
-    q->head = q->tail = q->store = gv_calloc((size_t)sz, sizeof(node_t*));
+    q->head = q->tail = q->store = gv_calloc(sz, sizeof(node_t*));
     q->limit = q->store + sz;
     return q;
 }
@@ -248,41 +247,6 @@ Agraphinfo_t* GD_info(graph_t * g) { return ((Agraphinfo_t*)AGDATA(g));}
 Agnodeinfo_t* ND_info(node_t * n) { return ((Agnodeinfo_t*)AGDATA(n));}
 #endif
 
-#if !defined(_WIN32)
-#include	<pwd.h>
-
-#endif
-
-/* Fgets:
- * Read a complete line.
- * Return pointer to line,
- * or 0 on EOF
- */
-char *Fgets(FILE * fp)
-{
-    static size_t bsize = 0;
-    static char *buf;
-    char *lp;
-    size_t len;
-
-    len = 0;
-    do {
-	if (bsize - len < BUFSIZ) {
-	    bsize += BUFSIZ;
-	    buf = grealloc(buf, bsize);
-	}
-	lp = fgets(buf + len, (int)(bsize - len), fp);
-	if (lp == 0)
-	    break;
-	len += strlen(lp);	/* since lp != NULL, len > 0 */
-    } while (buf[len - 1] != '\n');
-
-    if (len > 0)
-	return buf;
-    else
-	return 0;
-}
-
 /* safefile:
  * Check to make sure it is okay to read in files.
  * It returns NULL if the filename is trivial.
@@ -305,34 +269,26 @@ char *Fgets(FILE * fp)
 #define PATHSEP ":"
 #endif
 
-static strview_t *mkDirlist(const char *list, size_t *maxdirlen) {
+static strview_t *mkDirlist(const char *list) {
     size_t cnt = 0;
     strview_t *dirs = gv_calloc(1, sizeof(strview_t));
-    size_t maxlen = 0;
 
     for (tok_t t = tok(list, PATHSEP); !tok_end(&t); tok_next(&t)) {
         strview_t dir = tok_get(&t);
         dirs = gv_recalloc(dirs, cnt + 1, cnt + 2, sizeof(strview_t));
         dirs[cnt++] = dir;
-        maxlen = MAX(maxlen, dir.size);
     }
-    *maxdirlen = maxlen;
     return dirs;
 }
 
-static char *findPath(const strview_t *dirs, size_t maxdirlen, const char *str) {
-    static char *safefilename = NULL;
-
-	/* allocate a buffer that we are sure is big enough
-         * +1 for null character.
-         * +1 for directory separator character.
-         */
-    safefilename = realloc(safefilename, maxdirlen + strlen(str) + 2);
+static char *findPath(const strview_t *dirs, const char *str) {
+    static agxbuf safefilename;
 
     for (const strview_t *dp = dirs; dp != NULL && dp->data != NULL; dp++) {
-	sprintf(safefilename, "%.*s%s%s", (int)dp->size, dp->data, DIRSEP, str);
-	if (access (safefilename, R_OK) == 0)
-	    return safefilename;
+	agxbprint(&safefilename, "%.*s%s%s", (int)dp->size, dp->data, DIRSEP, str);
+	char *filename = agxbuse(&safefilename);
+	if (access(filename, R_OK) == 0)
+	    return filename;
     }
     return NULL;
 }
@@ -341,7 +297,6 @@ const char *safefile(const char *filename)
 {
     static bool onetime = true;
     static char *pathlist = NULL;
-    static size_t maxdirlen;
     static strview_t *dirs;
 
     if (!filename || !filename[0])
@@ -362,13 +317,13 @@ const char *safefile(const char *filename)
 	dirs = NULL;
 	pathlist = Gvimagepath;
 	if (pathlist && *pathlist)
-	    dirs = mkDirlist (pathlist, &maxdirlen);
+	    dirs = mkDirlist(pathlist);
     }
 
     if (*filename == DIRSEP[0] || !dirs)
 	return filename;
 
-    return findPath (dirs, maxdirlen, filename);
+    return findPath(dirs, filename);
 }
 
 int maptoken(char *p, char **name, int *val) {
@@ -529,7 +484,7 @@ void gvToggle(int s)
 #endif
 }
 
-int test_toggle()
+int test_toggle(void)
 {
     return Tflag;
 }
@@ -653,8 +608,6 @@ int common_init_edge(edge_t * e)
 	GD_has_labels(sg) |= EDGE_XLABEL;
     }
 
-
-    /* vladimir */
     if (E_headlabel && (str = agxget(e, E_headlabel)) && str[0]) {
 	initFontLabelEdgeAttr(e, &fi, &lfi);
 	ED_head_label(e) = make_label(e, str, aghtmlstr(str) ? LT_HTML : LT_NONE,
@@ -668,7 +621,6 @@ int common_init_edge(edge_t * e)
 				lfi.fontsize, lfi.fontname, lfi.fontcolor);
 	GD_has_labels(sg) |= TAIL_LABEL;
     }
-    /* end vladimir */
 
     /* We still accept ports beginning with colons but this is deprecated
      * That is, we allow tailport = ":abc" as well as the preferred
@@ -1103,15 +1055,13 @@ void processClusterEdges(graph_t * g)
     node_t *nxt;
     edge_t *e;
     graph_t *clg;
-    agxbuf xb;
+    agxbuf xb = {0};
     Dt_t *map;
     Dt_t *cmap = mkClustMap (g);
-    char buf[SMALLBUF];
 
     map = dtopen(&mapDisc, Dtoset);
     clg = agsubg(g, "__clusternodes",1);
     agbindrec(clg, "Agraphinfo_t", sizeof(Agraphinfo_t), true);
-    agxbinit(&xb, SMALLBUF, buf);
     for (n = agfstnode(g); n; n = agnxtnode(g, n)) {
 	if (IS_CLUST_NODE(n)) continue;
 	for (e = agfstout(g, n); e; e = agnxtout(g, e)) {
