@@ -25,13 +25,16 @@ extern "C" {
 #include <ast/ast.h>
 #include <inttypes.h>
 
-#undef	RS	/* hp.pa <signal.h> grabs this!! */
-
 #include <expr/exparse.h>
 
 #undef	extern
 
+#include <assert.h>
 #include <cdt.h>
+#include <cgraph/agxbuf.h>
+#include <stdarg.h>
+#include <stddef.h>
+#include <stdio.h>
 #include <vmalloc/vmalloc.h>
 
 #define EX_VERSION	20000101L
@@ -86,24 +89,15 @@ extern "C" {
 #define A(n,t)		((t)<<((n)*TBITS))	/* function arg n is type t     */
 #define N(t)		((t)>>=TBITS)	/* shift for next arg           */
 
-#define exalloc(p,n)		exnewof(p,0,char,n,0)
-#define exnewof(p,o,t,n,x)	vmnewof((p)->vm,o,t,n,x)
-#define exfree(p,x)		vmfree((p)->vm,x)
-#define exstrdup(p,s)		vmstrdup((p)->vm,s)
+#define exalloc(p,n)		vmalloc((p)->vm, (n))
 
-#if LONG_MAX > INT_MAX
-typedef int Exshort_t;
-#else
-typedef short Exshort_t;
-#endif
+typedef EX_STYPE Extype_t;
 
-typedef EXSTYPE Extype_t;
-
-union Exdata_u; typedef union Exdata_u Exdata_t;
-struct Exdisc_s; typedef struct Exdisc_s Exdisc_t;
-struct Exnode_s; typedef struct Exnode_s Exnode_t;
-struct Expr_s; typedef struct Expr_s Expr_t;
-struct Exref_s; typedef struct Exref_s Exref_t;
+typedef union Exdata_u Exdata_t;
+typedef struct Exdisc_s Exdisc_t;
+typedef struct Exnode_s Exnode_t;
+typedef struct Expr_s Expr_t;
+typedef struct Exref_s Exref_t;
 
 typedef int (*Exerror_f) (Expr_t *, Exdisc_t *, int, const char *, ...);
 typedef void (*Exexit_f) (Expr_t *, Exdisc_t *, int);
@@ -135,12 +129,6 @@ struct Exref_s				/* . reference list		*/
 	Exnode_t*	index;		/* optional reference index	*/
 };
 
-typedef struct Exbuf_s			/* sized buffer			*/
-{
-	uint64_t	size;		/* buffer size			*/
-	char*		data;		/* buffer data			*/
-} Exbuf_t;
-
 union Exdata_u
 {
 
@@ -180,10 +168,9 @@ union Exdata_u
 
 struct Exnode_s				/* expression tree node		*/
 {
-	Exshort_t	type;		/* value type			*/
-	Exshort_t	op;		/* operator			*/
-	Exshort_t	binary;		/* data.operand.{left,right} ok	*/
-	Exshort_t	pad_1;		/* padding to help cc		*/
+	int	type;		/* value type			*/
+	int	op;		/* operator			*/
+	int	binary;		/* data.operand.{left,right} ok	*/
 	Exlocal_t	local;		/* user defined local stuff	*/
 	union
 	{
@@ -209,24 +196,24 @@ struct Exdisc_s				/* discipline			*/
 	char*		type;		/* pathfind() type		*/
 	int		(*castf)(Expr_t*, Exnode_t*, const char*, int, Exid_t*, int, Exdisc_t*);
 					/* unknown cast function	*/
-	int		(*convertf)(Expr_t*, Exnode_t*, int, Exid_t*, int, Exdisc_t*);
+	int		(*convertf)(Exnode_t*, int, int);
 					/* type conversion function	*/
-	int		(*binaryf) (Expr_t *, Exnode_t *, Exnode_t *, Exnode_t *, int, Exdisc_t *);
+	int		(*binaryf) (Exnode_t *, Exnode_t *, Exnode_t *, int);
 					/* binary operator function     */
-	char*		(*typename) (Expr_t *, int);
+	char*		(*typename) (int);
 					/* application type names       */
-	int		(*stringof) (Expr_t *, Exnode_t *, int, Exdisc_t *);
+	int		(*stringof) (Expr_t *, Exnode_t *, int);
 					/* value to string conversion   */
-	Extype_t	(*keyf) (Expr_t *, Extype_t, int, Exdisc_t *);
+	Extype_t	(*keyf) (Extype_t, int);
 					/* dictionary key for external type objects     */
 	Exerror_f	errorf;		/* error function		*/
 	Extype_t	(*getf)(Expr_t*, Exnode_t*, Exid_t*, Exref_t*, void*, int, Exdisc_t*);
 					/* get value function		*/
-	Extype_t	(*reff)(Expr_t*, Exnode_t*, Exid_t*, Exref_t*, char*, int, Exdisc_t*);
+	Extype_t	(*reff)(Expr_t*, Exnode_t*, Exid_t*, Exref_t*);
 					/* reference value function	*/
-	int		(*setf)(Expr_t*, Exnode_t*, Exid_t*, Exref_t*, void*, int, Extype_t, Exdisc_t*);
+	int		(*setf)(Expr_t*, Exnode_t*, Exid_t*, Exref_t*, void*, Extype_t);
 					/* set value function		*/
-	int		(*matchf)(Expr_t*, Exnode_t*, const char*, Exnode_t*, const char*, void*, Exdisc_t*);
+	int		(*matchf)(const char*, const char*);
 	/* exit function           */
 	Exexit_f	exitf;
 	int*		types;
@@ -247,39 +234,34 @@ struct Expr_s				/* ex program state		*/
 
 };
 
-struct Excc_s; typedef struct Excc_s Excc_t;
-struct Exccdisc_s; typedef struct Exccdisc_s Exccdisc_t;
-
-struct Exccdisc_s			/* excc() discipline		*/
-{
-	Sfio_t*		text;		/* text output stream		*/
-	char*		id;		/* symbol prefix		*/
-	uint64_t	flags;		/* EXCC_* flags			*/
-	int		(*ccf)(Excc_t*, Exnode_t*, Exid_t*, Exref_t*, Exnode_t*, Exccdisc_t*);
-					/* program generator function	*/
-};
-
-struct Excc_s				/* excc() state			*/
-{
-	Expr_t*		expr;		/* exopen() state		*/
-	Exdisc_t*	disc;		/* exopen() discipline		*/
-
-#ifdef _EX_CC_PRIVATE_
-	_EX_CC_PRIVATE_
-#endif
-
-};
-
-
 extern Exnode_t*	excast(Expr_t*, Exnode_t*, int, Exnode_t*, int);
 extern Exnode_t*	exnoncast(Exnode_t *);
-extern int		exccclose(Excc_t*);
-extern Excc_t*		exccopen(Expr_t*, Exccdisc_t*);
 extern void		exclose(Expr_t*, int);
-extern int		excomp(Expr_t*, const char*, int, const char*, Sfio_t*);
+
+/** Compile an expression
+ *
+ * The callee takes ownership of the pointer \p prefix and will free it during
+ * \p expop or \p exclose.
+ *
+ * \param p Program structure to store result in
+ * \param name Filename of originating source file
+ * \param line Line number of originating source file
+ * \param fp Handle to source file
+ * \param prefix Optional program text to include ahead of the file content
+ * \return 0 on success
+ */
+extern int excomp(Expr_t *p, const char *name, int line, Sfio_t *fp,
+                  char *prefix);
+
 extern char*		excontext(Expr_t*, char*, int);
-extern int		exdump(Expr_t*, Exnode_t*, Sfio_t*);
+extern int		exdump(Expr_t*, Exnode_t*, agxbuf*);
+#ifdef __GNUC__
+__attribute__((format(printf, 1, 2)))
+#endif
 extern void		exerror(const char*, ...);
+#ifdef __GNUC__
+__attribute__((format(printf, 1, 2)))
+#endif
 extern void		exwarn(const char *, ...);
 extern Extype_t		exeval(Expr_t*, Exnode_t*, void*);
 extern Exnode_t*	exexpr(Expr_t*, const char*, Exid_t*, int);
@@ -288,13 +270,13 @@ extern Exnode_t*	exnewnode(Expr_t*, int, int, int, Exnode_t*, Exnode_t*);
 extern char*		exnospace(void);
 extern Expr_t*		exopen(Exdisc_t*);
 extern int		expop(Expr_t*);
-extern int		expush(Expr_t*, const char*, int, const char*, Sfio_t*);
+extern int		expush(Expr_t*, const char*, int, Sfio_t*);
 extern char*		exstash(Sfio_t*, Vmalloc_t*);
 extern int		extoken_fn(Expr_t*);
 extern char*		exstring(Expr_t *, char *);
-extern void*		exstralloc(Expr_t *, void *, size_t);
-extern char*		extype(int);
-extern Extype_t		exzero(int);
+extern void*		exstralloc(Expr_t *, size_t);
+extern char* extype(long int);
+extern Extype_t exzero(long int);
 extern char*	exopname(int);
 extern void		exinit(void);
 extern char*	extypename(Expr_t * p, int);
@@ -302,6 +284,42 @@ extern int		exisAssign(Exnode_t *);
 
 #undef	extern
 
+/** Construct a vmalloc-backed string.
+ *
+ * \param vm Allocator to use.
+ * \param fmt printf-style format sting.
+ * \param ... printf-style varargs.
+ * \return Dynamically allocated string.
+ */
+#ifdef __GNUC__
+__attribute__((format(printf, 2, 3)))
+#endif
+static inline char *exprintf(Vmalloc_t *vm, const char *fmt, ...) {
+  va_list ap;
+  va_start(ap, fmt);
+
+  // how many bytes do we need for this string?
+  va_list ap2;
+  va_copy(ap2, ap);
+  int len = vsnprintf(NULL, 0, fmt, ap2);
+  assert(len >= 0 && "invalid vsnprintf call");
+  ++len; // for NUL terminator
+  va_end(ap2);
+
+  // ask vmalloc for enough space for this
+  char *s = vmalloc(vm, (size_t)len);
+  if (s == NULL) {
+    va_end(ap);
+    return exnospace();
+  }
+
+  // construct the output string
+  (void)vsnprintf(s, (size_t)len, fmt, ap);
+  va_end(ap);
+
+  return s;
+}
+
 #endif
 
 #ifdef __cplusplus
