@@ -26,12 +26,6 @@
 
 #define SMALL 1.e-10
 
-#ifdef OPENGL
-#include <gl.h>
-extern pedge *edges_global;
-extern int *clusters_global;
-#endif
-
 static double norm(int n, double *x){
   double res = 0;
   int i;
@@ -205,7 +199,7 @@ void pedge_export_gv(FILE *fp, int ne, pedge *edges){
   pedge edge;
   double *x, t;
   int i, j, k, kk, dim, sta, sto;
-  double maxwgt = 0, len, len_total, len_total0;
+  double maxwgt = 0, len, len_total0;
   int r, g, b;
   double tt1[3]={0.15,0.5,0.85};
   double tt2[4]={0.15,0.4,0.6,0.85};
@@ -289,7 +283,6 @@ void pedge_export_gv(FILE *fp, int ne, pedge *edges){
 	fprintf(fp, "%f", edge->wgts[j]);
       }
 
-      len_total = 0;
       len_total0 = 0;
       fprintf(fp, "\", color=\"");
       for (j = 0; j < edge->npoints - 1; j++){
@@ -306,7 +299,6 @@ void pedge_export_gv(FILE *fp, int ne, pedge *edges){
 	  len += (edge->x[dim*j+k] - edge->x[dim*(j+1)+k])*(edge->x[dim*j+k] - edge->x[dim*(j+1)+k]);
 	}
 	len = sqrt(len/k);
-	len_total += len;
 	t = edge->wgts[j]/maxwgt;
 	/* interpotate between red (t = 1) to blue (t = 0) */
 	r = 255*t; g = 0; b = 255*(1-t); b = 255*(1-t);
@@ -446,7 +438,7 @@ static void edge_attraction_force(double similarity, pedge e1, pedge e2,
 
 }
 
-static pedge* force_directed_edge_bundling(SparseMatrix A, pedge* edges, int maxit, double step0, double K, int open_gl){
+static pedge* force_directed_edge_bundling(SparseMatrix A, pedge* edges, int maxit, double step0, double K) {
   int i, j, ne = A->n, k;
   int *ia = A->ia, *ja = A->ja, iter = 0;
   double *a = (double*) A->a;
@@ -482,7 +474,9 @@ static pedge* force_directed_edge_bundling(SparseMatrix A, pedge* edges, int max
 
       for (j = 1; j <= np - 2; j++){
 	for (k = 0; k < dim; k++) {
-	  x[j*dim + k] += step*edge_length*(force_t[j*dim+k] + K*force_a[j*dim+k])/(sqrt(fnorm_t*fnorm_t + K*K*fnorm_a*fnorm_a));
+	  x[j * dim + k] += step * edge_length
+	                  * (force_t[j * dim + k] + K * force_a[j * dim+k])
+	                  / hypot(fnorm_t, K * fnorm_a);
 	}
       }
       
@@ -490,23 +484,13 @@ static pedge* force_directed_edge_bundling(SparseMatrix A, pedge* edges, int max
     step = step*0.9;
   if (Verbose > 1)
     fprintf(stderr, "iter ==== %d cpu = %f npoints = %d\n",iter, ((double) (clock() - start))/CLOCKS_PER_SEC, np - 2);
-
-#ifdef OPENGL
-    if (open_gl){
-      edges_global = edges;
-      drawScene();
-    }
-#else
-    (void)open_gl;
-#endif
-
   }
 
   return edges;
 }
 
 static pedge* modularity_ink_bundling(int dim, int ne, SparseMatrix B, pedge* edges, double angle_param, double angle){
-  int *assignment = NULL, flag, nclusters;
+  int *assignment = NULL, nclusters;
   double modularity;
   int *clusterp, *clusters;
   SparseMatrix D, C;
@@ -514,28 +498,22 @@ static pedge* modularity_ink_bundling(int dim, int ne, SparseMatrix B, pedge* ed
   double ink0, ink1;
   pedge e;
   int i, j, jj;
-  int use_value_for_clustering = TRUE;
 
   SparseMatrix BB;
 
   /* B may contain negative entries */
   BB = SparseMatrix_copy(B);
   BB = SparseMatrix_apply_fun(BB, fabs);
-  modularity_clustering(BB, TRUE, 0, use_value_for_clustering, &nclusters, &assignment, &modularity, &flag);
+  modularity_clustering(BB, true, 0, &nclusters, &assignment, &modularity);
   SparseMatrix_delete(BB);
 
-#ifdef OPENGL
-  clusters_global = assignment;
-#endif
-
-  assert(!flag);
   if (Verbose > 1) fprintf(stderr, "there are %d clusters, modularity = %f\n",nclusters, modularity);
   
   C = SparseMatrix_new(1, 1, 1, MATRIX_TYPE_PATTERN, FORMAT_COORD);
   
   for (i = 0; i < ne; i++){
     jj = assignment[i];
-    SparseMatrix_coordinate_form_add_entries(C, 1, &jj, &i, NULL);
+    SparseMatrix_coordinate_form_add_entry(C, jj, i, NULL);
   }
   
   D = SparseMatrix_from_coordinate_format(C);
@@ -559,10 +537,6 @@ static pedge* modularity_ink_bundling(int dim, int ne, SparseMatrix B, pedge* ed
 	e->x[3*dim+1] = e->x[4*dim+1];
 	e->npoints = 4;
       }
-#ifdef OPENGL
-      edges_global = edges;
-      drawScene();
-#endif
     }
   }
   SparseMatrix_delete(D);
@@ -590,8 +564,8 @@ static SparseMatrix check_compatibility(SparseMatrix A, int ne, pedge *edges, in
       } 
 
       if (fabs(dist) > tol){
-	B = SparseMatrix_coordinate_form_add_entries(B, 1, &i, &jj, &dist);
-	B = SparseMatrix_coordinate_form_add_entries(B, 1, &jj, &i, &dist);
+	B = SparseMatrix_coordinate_form_add_entry(B, i, jj, &dist);
+	B = SparseMatrix_coordinate_form_add_entry(B, jj, i, &dist);
       }
     }
   }
@@ -604,7 +578,7 @@ static SparseMatrix check_compatibility(SparseMatrix A, int ne, pedge *edges, in
 }
 
 pedge* edge_bundling(SparseMatrix A0, int dim, double *x, int maxit_outer, double K, int method, int nneighbor, int compatibility_method,
-		     int max_recursion, double angle_param, double angle, int open_gl){
+		     int max_recursion, double angle_param, double angle){
   /* bundle edges. 
      A: edge graph
      x: edge i is at {p,q}, 
@@ -616,7 +590,6 @@ pedge* edge_bundling(SparseMatrix A0, int dim, double *x, int maxit_outer, doubl
      nneighbor: number of neighbors to be used in forming nearest neighbor graph. Used only in agglomerative method
      compatibility_method: which method to use to calculate compatibility. Used only in force directed.
      max_recursion: used only in agglomerative method. Specify how many level of recursion to do to bundle bundled edges again
-     open_gl: whether to plot in X.
 
   */
   int ne = A0->m;
@@ -627,7 +600,6 @@ pedge* edge_bundling(SparseMatrix A0, int dim, double *x, int maxit_outer, doubl
   int k;
   double step0 = 0.1, start = 0.0;
   int maxit = 10;
-  int flag; 
 
   assert(A->n == ne);
   edges = (pedge*)MALLOC(sizeof(pedge)*ne);
@@ -651,9 +623,10 @@ pedge* edge_bundling(SparseMatrix A0, int dim, double *x, int maxit_outer, doubl
   } else if (method == METHOD_INK_AGGLOMERATE){
 #ifdef HAVE_ANN
     /* plan: merge a node with its neighbors if doing so improve. Form coarsening graph, repeat until no more ink saving */
-    edges = agglomerative_ink_bundling(dim, A, edges, nneighbor, max_recursion, angle_param, angle, open_gl, &flag);
-    assert(!flag);
+    edges = agglomerative_ink_bundling(dim, A, edges, nneighbor, max_recursion, angle_param, angle);
 #else
+    (void)max_recursion;
+    (void)nneighbor;
     agerr (AGERR, "Graphviz built without approximate nearest neighbor library ANN; agglomerative inking not available\n");
     edges = edges;
 #endif
@@ -668,7 +641,7 @@ pedge* edge_bundling(SparseMatrix A0, int dim, double *x, int maxit_outer, doubl
 	edges[i] = pedge_double(edges[i]);
       }
       step0 /= 2;
-      edges = force_directed_edge_bundling(B, edges, maxit, step0, K, open_gl);
+      edges = force_directed_edge_bundling(B, edges, maxit, step0, K);
     }
     
   } else if (method == METHOD_NONE){
