@@ -114,8 +114,6 @@ extern "C" {
 #define ushort		unsigned short
 #endif
 
-#define SECOND		1000	/* millisecond units */
-
 /* macros do determine stream types from Stat_t data */
 #ifndef S_IFMT
 #define S_IFMT	0
@@ -162,14 +160,14 @@ extern "C" {
 /* function to get the decimal point for local environment */
 #include	<locale.h>
 #define SFSETLOCALE(decimal,thousand) \
-	{ struct lconv*	lv; \
+	{ struct lconv*	lv_; \
 	  if((decimal) == 0) \
 	  { (decimal) = '.'; \
-	    if((lv = localeconv())) \
-	    { if(lv->decimal_point && lv->decimal_point[0]) \
-	    	(decimal) = lv->decimal_point[0]; \
-	      if(lv->thousands_sep && lv->thousands_sep[0]) \
-	    	(thousand) = lv->thousands_sep[0]; \
+	    if((lv_ = localeconv())) \
+	    { if(lv_->decimal_point && lv_->decimal_point[0]) \
+	    	(decimal) = lv_->decimal_point[0]; \
+	      if(lv_->thousands_sep && lv_->thousands_sep[0]) \
+	    	(thousand) = lv_->thousands_sep[0]; \
 	    } \
 	  } \
 	}
@@ -192,17 +190,6 @@ extern "C" {
 	uchar data[1];		/* data buffer                  */
     };
 
-/* co-process structure */
-    typedef struct _sfproc_s Sfproc_t;
-    struct _sfproc_s {
-	int pid;		/* process id                   */
-	uchar *rdata;		/* read data being cached       */
-	int ndata;		/* size of cached data          */
-	int size;		/* buffer size                  */
-	int file;		/* saved file descriptor        */
-	int sigp;		/* sigpipe protection needed    */
-    };
-
 /* extensions to sfvprintf/sfvscanf */
 #define FP_SET(fp,fn)	(fp < 0 ? (fn += 1) : (fn = fp) )
 #define FP_WIDTH	0
@@ -271,7 +258,6 @@ extern "C" {
 	 (sz == 64 && sz == sizeof(type)*CHAR_BIT) )
 
 /* format flags&types, must coexist with those in sfio.h */
-#define SFFMT_FORBIDDEN 00077777777	/* for sfio.h only      */
 #define SFFMT_EFORMAT	01000000000	/* sfcvt converting %e  */
 #define SFFMT_MINUS	02000000000	/* minus sign           */
 
@@ -313,7 +299,6 @@ extern "C" {
 
 /* grain size for buffer increment */
 #define SF_GRAIN	1024
-#define SF_PAGE		((ssize_t)(SF_GRAIN*sizeof(int)*2))
 
 /* when the buffer is empty, certain io requests may be better done directly
    on the given application buffers. The below condition determines when.
@@ -347,7 +332,7 @@ extern "C" {
 #define SFSYNC(f)	(SETLOCAL(f),sfsync(f))
 #define SFCLOSE(f)	(SETLOCAL(f),sfclose(f))
 #define SFFLSBUF(f,n)	(SETLOCAL(f),_sfflsbuf(f,n))
-#define SFFILBUF(f,n)	(SETLOCAL(f),_sffilbuf(f,n))
+#define SFFILBUF(f)	(SETLOCAL(f), _sffilbuf(f ,-1))
 #define SFSETBUF(f,s,n)	(SETLOCAL(f),sfsetbuf(f,s,n))
 #define SFWRITE(f,s,n)	(SETLOCAL(f),sfwrite(f,s,n))
 #define SFREAD(f,s,n)	(SETLOCAL(f),sfread(f,s,n))
@@ -398,7 +383,7 @@ extern "C" {
 /* fast peek of a stream */
 #define _SFAVAIL(f,s,n)	((n) = (f)->endb - ((s) = (f)->next) )
 #define SFRPEEK(f,s,n)	(_SFAVAIL(f,s,n) > 0 ? (n) : \
-				((n) = SFFILBUF(f,-1), (s) = (f)->next, (n)) )
+				((n) = SFFILBUF(f), (s) = (f)->next, (n)) )
 #define SFWPEEK(f,s,n)	(_SFAVAIL(f,s,n) > 0 ? (n) : \
 				((n) = SFFLSBUF(f,-1), (s) = (f)->next, (n)) )
 
@@ -409,9 +394,9 @@ extern "C" {
 #define CLOSE(f)	{ while(close(f) < 0 && errno == EINTR) errno = 0; }
 
 /* string stream extent */
-#define SFSTRSIZE(f)	{ Sfoff_t s = (f)->next - (f)->data; \
-			  if(s > (f)->here) \
-			    { (f)->here = s; if(s > (f)->extent) (f)->extent = s; } \
+#define SFSTRSIZE(f)	{ Sfoff_t s_ = (f)->next - (f)->data; \
+			  if(s_ > (f)->here) \
+			    { (f)->here = s_; if(s_ > (f)->extent) (f)->extent = s_; } \
 			}
 
 /* control flags for open() */
@@ -446,7 +431,6 @@ extern "C" {
 
 /* floating point to ascii conversion */
 #define SF_MAXEXP10	6
-#define SF_MAXPOW10	(1 << SF_MAXEXP10)
 #define SF_FDIGITS	256	/* max allowed fractional digits */
 #define SF_IDIGITS	1024	/* max number of digits in int part */
 #define SF_MAXDIGITS	(((SF_FDIGITS+SF_IDIGITS)/sizeof(int) + 1)*sizeof(int))
@@ -458,7 +442,6 @@ extern "C" {
 #define _Sfdigits	(_Sftable.sf_digits)
 #define _Sfcvinitf	(_Sftable.sf_cvinitf)
 #define _Sfcvinit	(_Sftable.sf_cvinit)
-#define _Sffmtposf	(_Sftable.sf_fmtposf)
 #define _Sffmtintf	(_Sftable.sf_fmtintf)
 #define _Sfcv36		(_Sftable.sf_cv36)
 #define _Sfcv64		(_Sftable.sf_cv64)
@@ -470,7 +453,6 @@ extern "C" {
 	char *sf_digits;	/* digits for general bases     */
 	int (*sf_cvinitf) (void);	/* initialization function      */
 	int sf_cvinit;		/* initialization state         */
-	Fmtpos_t *(*sf_fmtposf) (Sfio_t *, const char *, va_list, int);
 	char *(*sf_fmtintf) (const char *, int *);
 	uchar sf_cv36[UCHAR_MAX + 1];	/* conversion for base [2-36]   */
 	uchar sf_cv64[UCHAR_MAX + 1];	/* conversion for base [37-64]  */
@@ -526,14 +508,9 @@ extern "C" {
 	  } \
 	}
 
-/* handy functions */
+// handy function
 #undef min
-#undef max
 #define min(x,y)	((x) < (y) ? (x) : (y))
-#define max(x,y)	((x) > (y) ? (x) : (y))
-
-/* fast functions for memory copy and memory clear */
-#define memclear(s,n)	memset((s),'\0',(n))
 
 /* note that MEMCPY advances the associated pointers */
 #define MEMCPY(to,fr,n) \
@@ -542,22 +519,12 @@ extern "C" {
     extern Sfextern_t _Sfextern;
     extern Sftab_t _Sftable;
 
-    extern int _sfpopen(Sfio_t *, int, int, int);
-    extern int _sfpclose(Sfio_t *);
     extern int _sfmode(Sfio_t *, int, int);
-    extern int _sftype(const char *, int *, int *);
     extern int _sfexcept(Sfio_t *, int, ssize_t, Sfdisc_t *);
     extern Sfrsrv_t *_sfrsrv(Sfio_t *, ssize_t);
     extern int _sfsetpool(Sfio_t *);
     extern char *_sfcvt(void *, int, int *, int *, int);
 
-#ifdef _WIN32
-#undef SF_ERROR
-#include <io.h>
-#define SF_ERROR	0000400	/* an error happened                    */
-#else
-#endif /* _WIN32 */
-
 #ifdef __cplusplus
 }
 #endif
