@@ -56,23 +56,6 @@ extern "C" {
 	Sfdisc_t *disc;		/* the continuing discipline    */
     };
 
-/* a file structure */
-    struct _sfio_s {
-	unsigned char *next;	/* next position to read/write from     */
-	unsigned char *endw;	/* end of write buffer                  */
-	unsigned char *endr;	/* end of read buffer                   */
-	unsigned char *endb;	/* end of buffer                        */
-	Sfio_t *push;		/* the stream that was pushed on        */
-	unsigned short flags;	/* type of stream                       */
-	short file;		/* file descriptor                      */
-	unsigned char *data;	/* base of data buffer                  */
-	ssize_t size;		/* buffer size                          */
-	ssize_t val;		/* values or string lengths             */
-#ifdef _SFIO_PRIVATE
-	 _SFIO_PRIVATE
-#endif
-    };
-
 /* formatting environment */
     typedef struct _sffmt_s Sffmt_t;
     typedef int (*Sffmtext_f)(void *, Sffmt_t *);
@@ -190,12 +173,10 @@ extern "C" {
     extern ssize_t sfread(Sfio_t *, void *, size_t);
     extern ssize_t sfwrite(Sfio_t *, const void *, size_t);
     extern int sfclose(Sfio_t *);
-    extern Sfoff_t sfseek(Sfio_t *, Sfoff_t, int);
-    extern ssize_t sfputr(Sfio_t *, const char *, int);
+    extern ssize_t sfputr(Sfio_t*, const char*);
     extern ssize_t sfnputc(Sfio_t *, int, size_t);
     extern int sfungetc(Sfio_t *, int);
-    extern int sfprintf(Sfio_t *, const char *, ...);
-    extern int sfvprintf(Sfio_t *, const char *, va_list);
+    extern int sfprint(Sfio_t*, Sffmt_t *format);
     extern int sfscanf(Sfio_t *, const char *, ...);
     extern int sfsscanf(const char *, const char *, ...);
     extern int sfvsscanf(const char *, const char *, va_list);
@@ -205,7 +186,7 @@ extern "C" {
     extern ssize_t sfrd(Sfio_t *, void *, size_t, Sfdisc_t *);
     extern ssize_t sfwr(Sfio_t *, const void *, size_t, Sfdisc_t *);
     extern Sfoff_t sfsk(Sfio_t *, Sfoff_t, int, Sfdisc_t *);
-    extern ssize_t sfpkrd(int, void *, size_t, int, long, int);
+    extern ssize_t sfpkrd(int, void *, size_t, int, int);
 
     extern int sfputc(Sfio_t *, int);
 
@@ -221,23 +202,6 @@ extern "C" {
 
 #undef extern
 
-#if defined(__cplusplus)
-#define _SF_(f)		(f)
-#else
-#define _SF_(f)		((Sfio_t*)(f))
-#endif
-#define __sf_putc(f,c)	(_SF_(f)->next >= _SF_(f)->endw ? \
-			 _sfflsbuf(_SF_(f),(int)((unsigned char)(c))) : \
-			 (int)(*_SF_(f)->next++ = (unsigned char)(c)) )
-#define __sf_getc(f)	(_SF_(f)->next >= _SF_(f)->endr ? _sffilbuf(_SF_(f),0) : \
-			 (int)(*_SF_(f)->next++) )
-#define __sf_fileno(f)	((f) ? _SF_(f)->file : -1)
-#define __sf_slen()	(_Sfi)
-
-#define sfputc(f,c)				( __sf_putc((f),(c))		)
-#define sfgetc(f)				( __sf_getc(f)			)
-#define sffileno(f)				( __sf_fileno(f)		)
-#define sfslen()				( __sf_slen()			)
 #ifdef __cplusplus
 }
 #endif
