@@ -10,7 +10,12 @@
 
 #pragma once
 
-#include "stdio.h"
+#include <stdio.h>
+
+#ifdef __cplusplus
+extern "C" {
+#endif
+
 enum {MAX_COLOR = 1001};
 
 enum {npalettes = 265};
@@ -18,7 +23,6 @@ extern int knownColorScheme(const char*);
 extern char *color_palettes[npalettes][2];
   /* return a list of rgb in hex form: "#ff0000,#00ff00,..." */
 extern char *color_palettes_get(char *color_palette_name);
-extern void color_palettes_name_print(FILE *fp);
 extern int color_palettes_Q(const char *color_palette_name);
 
 extern float palette_pastel[1001][3];
@@ -31,3 +35,7 @@ extern float palette_sequential_singlehue_red[1001][3];
 extern float palette_sequential_singlehue_red_lighter[1001][3];
 extern float palette_adam_blend[1001][3];
 extern float palette_adam[11][3];
+
+#ifdef __cplusplus
+}
+#endif
