@@ -646,12 +646,7 @@ static void svg_ellipse(GVJ_t * job, pointf * A, int filled)
 }
 
 static void
-svg_bezier(GVJ_t * job, pointf * A, int n, int arrow_at_start,
-	   int arrow_at_end, int filled)
-{
-    (void)arrow_at_start;
-    (void)arrow_at_end;
-
+svg_bezier(GVJ_t *job, pointf *A, int n, int filled) {
     int gid = 0;
     obj_state_t *obj = job->obj;
   
@@ -821,7 +816,7 @@ gvplugin_installed_t gvrender_svg_types[] = {
 
 gvplugin_installed_t gvdevice_svg_types[] = {
     {FORMAT_SVG, "svg:svg", 1, NULL, &device_features_svg},
-#if HAVE_LIBZ
+#ifdef HAVE_LIBZ
     {FORMAT_SVGZ, "svgz:svg", 1, NULL, &device_features_svgz},
 #endif
     {0, NULL, 0, NULL, NULL}
